==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/lv-LV/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Par aktīviem',
    'about_assets_text'            => 'Aktīvi ir posteņi, ko izseko pēc sērijas numura vai aktīvu taga. Viņi mēdz būt augstākas vērtības priekšmeti, kad ir svarīgi noteikt konkrētu objektu.',
    'archived'  				=> 'Arhivēts',
    'asset'  					=> 'Aktīvs',
    'bulk_checkout'             => 'Lielapjoma izsniegšana',
    'bulk_checkin'              => 'Checkin Assets',
    'checkin'  					=> 'Reģistrēšanās aktīvs',
    'checkout'  				=> 'Checkout Asset',
    'clone'  					=> 'Clone Asset',
    'deployable'  				=> 'Izvietojams',
    'deleted'  					=> 'Šis pamatlīdzeklis ir izdzēsts.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'Rediģēt īpašumu',
    'model_deleted'  			=> 'Šis pamatlīdzekļu modelis ir dzēsts. Jums ir jāatjauno modelis pirms drīkstiet atjaunot pamatlīdzekli.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'Pieļaujams',
    'requested'				    => 'Pieprasīts',
    'not_requestable'           => 'Nav pieprasāms',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'Atjaunot aktīvus',
    'pending'  					=> 'Gaida',
    'undeployable'  			=> 'Nodarbināms',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'Skatīt aktīvu',
    'csv_error' => 'Jūsu CSV failā ir kļūda:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'Error messages:',
    'success_messages' => 'Success messages:',
    'alert_details' => 'Lūdzu skatiet zemāk.',
    'custom_export' => 'Custom Export',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'User Department',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lv-LV/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Par aktīviem',
    'about_assets_text'            => 'Aktīvi ir posteņi, ko izseko pēc sērijas numura vai aktīvu taga. Viņi mēdz būt augstākas vērtības priekšmeti, kad ir svarīgi noteikt konkrētu objektu.',
    'archived'  				=> 'Arhivēts',
    'asset'  					=> 'Aktīvs',
    'bulk_checkout'             => 'Bulk Checkout',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'Reģistrēšanās aktīvs',
    'checkout'  				=> 'Checkout Asset',
    'clone'  					=> 'Clone Asset',
    'deployable'  				=> 'Izvietojams',
    'deleted'  					=> 'Šis pamatlīdzeklis ir izdzēsts.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'Rediģēt īpašumu',
    'model_deleted'  			=> 'Šis pamatlīdzekļu modelis ir dzēsts. Jums ir jāatjauno modelis pirms drīkstiet atjaunot pamatlīdzekli.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'Pieļaujams',
    'requested'				    => 'Pieprasīts',
    'not_requestable'           => 'Nav pieprasāms',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'Atjaunot aktīvus',
    'pending'  					=> 'Gaida',
    'undeployable'  			=> 'Nodarbināms',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'Skatīt aktīvu',
    'csv_error' => 'Jūsu CSV failā ir kļūda:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'Error messages:',
    'success_messages' => 'Success messages:',
    'alert_details' => 'Lūdzu skatiet zemāk.',
    'custom_export' => 'Custom Export',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'User Department',
];
